[Libreoffice-commits] .: sc/inc sc/qa sc/source

Cédric Bosdonnat cbosdo at kemper.freedesktop.org
Mon Mar 28 02:28:28 PDT 2011


 sc/inc/attarray.hxx                    |    5 ++--
 sc/inc/attrib.hxx                      |    4 +--
 sc/inc/cellsuno.hxx                    |    7 +++---
 sc/inc/column.hxx                      |    5 ++--
 sc/inc/document.hxx                    |   13 ++++++-----
 sc/inc/table.hxx                       |    6 ++---
 sc/qa/unit/ucalc.cxx                   |    2 -
 sc/source/core/data/attarray.cxx       |    1 
 sc/source/core/data/attrib.cxx         |    2 -
 sc/source/core/data/column.cxx         |    1 
 sc/source/core/data/document.cxx       |    1 
 sc/source/core/data/dpoutput.cxx       |    2 -
 sc/source/core/data/fillinfo.cxx       |    2 -
 sc/source/core/data/scdpoutputimpl.cxx |    4 +--
 sc/source/core/data/stlpool.cxx        |    2 -
 sc/source/core/data/table2.cxx         |    2 -
 sc/source/core/tool/autoform.cxx       |    2 -
 sc/source/filter/excel/xestyle.cxx     |    8 +++---
 sc/source/filter/excel/xistyle.cxx     |   38 ++++++++++++++++-----------------
 sc/source/filter/html/htmlexp.cxx      |   29 +++++++++++++------------
 sc/source/filter/html/htmlpars.cxx     |    6 ++---
 sc/source/filter/inc/excrecds.hxx      |    2 -
 sc/source/filter/inc/htmlexp.hxx       |    5 ++--
 sc/source/filter/inc/lotattr.hxx       |    5 ++--
 sc/source/filter/inc/lotimpop.hxx      |    1 
 sc/source/filter/lotus/lotattr.cxx     |    8 +++---
 sc/source/filter/starcalc/scflt.cxx    |    6 ++---
 sc/source/ui/inc/autofmt.hxx           |   30 +++++++++++++-------------
 sc/source/ui/inc/tabvwsh.hxx           |    9 ++++---
 sc/source/ui/inc/viewfunc.hxx          |   11 +++++----
 sc/source/ui/miscdlgs/autofmt.cxx      |    2 -
 sc/source/ui/unoobj/cellsuno.cxx       |    8 +++---
 sc/source/ui/view/formatsh.cxx         |   14 ++++++------
 sc/source/ui/view/output.cxx           |   14 ++++++------
 sc/source/ui/view/printfun.cxx         |    2 -
 sc/source/ui/view/tabvwsh4.cxx         |    2 -
 sc/source/ui/view/tabvwsh8.cxx         |    4 +--
 sc/source/ui/view/viewfun2.cxx         |    1 
 38 files changed, 138 insertions(+), 128 deletions(-)

New commits:
commit e1354a825cabf06bff94bcb79f5d184742ddf837
Author: Cédric Bosdonnat <cedricbosdo at openoffice.org>
Date:   Fri Mar 25 15:51:46 2011 +0100

    Moved SvxBorder* into editeng namespace to avoid duplicate DOUBLE on windows

diff --git a/sc/inc/attarray.hxx b/sc/inc/attarray.hxx
index 67b4959..dcf58aa 100644
--- a/sc/inc/attarray.hxx
+++ b/sc/inc/attarray.hxx
@@ -42,10 +42,11 @@ class ScFlatBoolRowSegments;
 class Rectangle;
 class SfxItemPoolCache;
 class SfxStyleSheetBase;
-class SvxBorderLine;
 class SvxBoxItem;
 class SvxBoxInfoItem;
 
+namespace editeng { class SvxBorderLine; }
+
 #define SC_LINE_EMPTY			0
 #define SC_LINE_SET				1
 #define SC_LINE_DONTCARE		2
@@ -136,7 +137,7 @@ public:
                             ScEditDataArray* pDataArray = NULL );
     bool    SetAttrEntries(ScAttrEntry* pNewData, SCSIZE nSize);
     void	ApplyLineStyleArea( SCROW nStartRow, SCROW nEndRow,
-                                const SvxBorderLine* pLine, sal_Bool bColorOnly );
+                                const ::editeng::SvxBorderLine* pLine, sal_Bool bColorOnly );
 
     void	ClearItems( SCROW nStartRow, SCROW nEndRow, const sal_uInt16* pWhich );
     void	ChangeIndent( SCROW nStartRow, SCROW nEndRow, sal_Bool bIncrement );
diff --git a/sc/inc/attrib.hxx b/sc/inc/attrib.hxx
index 46fecd2..a7e21b7 100644
--- a/sc/inc/attrib.hxx
+++ b/sc/inc/attrib.hxx
@@ -53,9 +53,9 @@
 
 
 class EditTextObject;
-class SvxBorderLine;
+namespace editeng { class SvxBorderLine; }
 
-sal_Bool SC_DLLPUBLIC ScHasPriority( const SvxBorderLine* pThis, const SvxBorderLine* pOther );
+sal_Bool SC_DLLPUBLIC ScHasPriority( const ::editeng::SvxBorderLine* pThis, const ::editeng::SvxBorderLine* pOther );
 
 //------------------------------------------------------------------------
 
diff --git a/sc/inc/cellsuno.hxx b/sc/inc/cellsuno.hxx
index 46c77ec..c90b306 100644
--- a/sc/inc/cellsuno.hxx
+++ b/sc/inc/cellsuno.hxx
@@ -108,11 +108,12 @@ class ScCellRangeObj;
 class SvxUnoText;
 class ScLinkListener;
 class ScPatternAttr;
-class SvxBorderLine;
 class SvxBoxItem;
 class SvxBoxInfoItem;
 class SvxItemPropertySet;
 
+namespace editeng { class SvxBorderLine; }
+
 class ScLinkListener : public SvtListener
 {
     Link	aLink;
@@ -139,9 +140,9 @@ SV_DECL_PTRARR_DEL( ScNamedEntryArr_Impl, ScNamedEntryPtr, 4, 4 )
 class ScHelperFunctions
 {
 public:
-    static const SvxBorderLine* GetBorderLine( SvxBorderLine& rLine, const com::sun::star::table::BorderLine& rStruct );
+    static const ::editeng::SvxBorderLine* GetBorderLine( ::editeng::SvxBorderLine& rLine, const com::sun::star::table::BorderLine& rStruct );
     static void FillBoxItems( SvxBoxItem& rOuter, SvxBoxInfoItem& rInner, const com::sun::star::table::TableBorder& rBorder );
-    static void FillBorderLine( com::sun::star::table::BorderLine& rStruct, const SvxBorderLine* pLine );
+    static void FillBorderLine( com::sun::star::table::BorderLine& rStruct, const ::editeng::SvxBorderLine* pLine );
     static void FillTableBorder( com::sun::star::table::TableBorder& rBorder,
                             const SvxBoxItem& rOuter, const SvxBoxInfoItem& rInner );
     static void ApplyBorder( ScDocShell* pDocShell, const ScRangeList& rRanges,
diff --git a/sc/inc/column.hxx b/sc/inc/column.hxx
index e4ab44b..dcd7b64 100644
--- a/sc/inc/column.hxx
+++ b/sc/inc/column.hxx
@@ -36,6 +36,8 @@
 
 #include <set>
 
+namespace editeng { class SvxBorderLine; }
+
 class Fraction;
 class OutputDevice;
 class Rectangle;
@@ -45,7 +47,6 @@ class SfxItemSet;
 class SvtListener;
 class SfxPoolItem;
 class SfxStyleSheetBase;
-class SvxBorderLine;
 class SvxBoxInfoItem;
 class SvxBoxItem;
 
@@ -333,7 +334,7 @@ public:
     void        ApplyStyleArea( SCROW nStartRow, SCROW nEndRow, const ScStyleSheet& rStyle );
     void        ApplySelectionStyle(const ScStyleSheet& rStyle, const ScMarkData& rMark);
     void        ApplySelectionLineStyle( const ScMarkData& rMark,
-                                    const SvxBorderLine* pLine, bool bColorOnly );
+                                    const ::editeng::SvxBorderLine* pLine, bool bColorOnly );
 
     const ScStyleSheet* GetStyle( SCROW nRow ) const;
     const ScStyleSheet* GetSelectionStyle( const ScMarkData& rMark, bool& rFound ) const;
diff --git a/sc/inc/document.hxx b/sc/inc/document.hxx
index 782e80e..bec764d 100644
--- a/sc/inc/document.hxx
+++ b/sc/inc/document.hxx
@@ -51,6 +51,8 @@
 #include <list>
 #include <boost/ptr_container/ptr_vector.hpp>
 
+namespace editeng { class SvxBorderLine; }
+
 class KeyEvent;
 class OutputDevice;
 class SdrObject;
@@ -67,7 +69,6 @@ class SfxStatusBarManager;
 class SfxStyleSheetBase;
 class SvMemoryStream;
 class SvNumberFormatter;
-class SvxBorderLine;
 class SvxBoxInfoItem;
 class SvxBoxItem;
 class SvxBrushItem;
@@ -841,10 +842,10 @@ public:
     SC_DLLPUBLIC bool HasAttrib( const ScRange& rRange, sal_uInt16 nMask ) const;
 
     void			GetBorderLines( SCCOL nCol, SCROW nRow, SCTAB nTab,
-                                    const SvxBorderLine** ppLeft,
-                                    const SvxBorderLine** ppTop,
-                                    const SvxBorderLine** ppRight,
-                                    const SvxBorderLine** ppBottom ) const;
+                                    const ::editeng::SvxBorderLine** ppLeft,
+                                    const ::editeng::SvxBorderLine** ppTop,
+                                    const ::editeng::SvxBorderLine** ppRight,
+                                    const ::editeng::SvxBorderLine** ppBottom ) const;
 
     void			ResetChanged( const ScRange& rRange );
 
@@ -1216,7 +1217,7 @@ public:
 
     void			ApplySelectionStyle( const ScStyleSheet& rStyle, const ScMarkData& rMark );
     void			ApplySelectionLineStyle( const ScMarkData& rMark,
-                                            const SvxBorderLine* pLine, sal_Bool bColorOnly );
+                                            const ::editeng::SvxBorderLine* pLine, sal_Bool bColorOnly );
 
     const ScStyleSheet*	GetStyle( SCCOL nCol, SCROW nRow, SCTAB nTab ) const;
     const ScStyleSheet*	GetSelectionStyle( const ScMarkData& rMark ) const;
diff --git a/sc/inc/table.hxx b/sc/inc/table.hxx
index 7b4a8dd..75a2e59 100644
--- a/sc/inc/table.hxx
+++ b/sc/inc/table.hxx
@@ -505,8 +505,8 @@ public:
     void		FindMaxRotCol( RowInfo* pRowInfo, SCSIZE nArrCount, SCCOL nX1, SCCOL nX2 );
 
     void		GetBorderLines( SCCOL nCol, SCROW nRow,
-                                const SvxBorderLine** ppLeft, const SvxBorderLine** ppTop,
-                                const SvxBorderLine** ppRight, const SvxBorderLine** ppBottom ) const;
+                                const ::editeng::SvxBorderLine** ppLeft, const ::editeng::SvxBorderLine** ppTop,
+                                const ::editeng::SvxBorderLine** ppRight, const ::editeng::SvxBorderLine** ppBottom ) const;
 
     bool        HasAttrib( SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2, sal_uInt16 nMask ) const;
     bool        HasAttribSelection( const ScMarkData& rMark, sal_uInt16 nMask ) const;
@@ -557,7 +557,7 @@ public:
     void		ApplyStyleArea( SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol, SCROW nEndRow, const ScStyleSheet& rStyle );
     void		ApplySelectionStyle(const ScStyleSheet& rStyle, const ScMarkData& rMark);
     void		ApplySelectionLineStyle( const ScMarkData& rMark,
-                                    const SvxBorderLine* pLine, sal_Bool bColorOnly );
+                                    const ::editeng::SvxBorderLine* pLine, sal_Bool bColorOnly );
 
     const ScStyleSheet*	GetStyle( SCCOL nCol, SCROW nRow ) const;
     const ScStyleSheet*	GetSelectionStyle( const ScMarkData& rMark, sal_Bool& rFound ) const;
diff --git a/sc/qa/unit/ucalc.cxx b/sc/qa/unit/ucalc.cxx
index e4deb3a..b5f2542 100644
--- a/sc/qa/unit/ucalc.cxx
+++ b/sc/qa/unit/ucalc.cxx
@@ -1128,7 +1128,7 @@ void Test::testDataArea()
     CPPUNIT_ASSERT_MESSAGE("Sheet is expected to be empty.", m_pDoc->IsBlockEmpty(0, 0, 0, 100, 100));
 
     // Now, set borders in some cells....
-    SvxBorderLine aLine(NULL, 50, SOLID);
+    ::editeng::SvxBorderLine aLine(NULL, 50, ::editeng::SOLID);
     SvxBoxItem aBorderItem(ATTR_BORDER);
     aBorderItem.SetLine(&aLine, BOX_LINE_LEFT);
     aBorderItem.SetLine(&aLine, BOX_LINE_RIGHT);
diff --git a/sc/source/core/data/attarray.cxx b/sc/source/core/data/attarray.cxx
index 1ec370a..6741093 100644
--- a/sc/source/core/data/attarray.cxx
+++ b/sc/source/core/data/attarray.cxx
@@ -59,6 +59,7 @@
 // STATIC DATA -----------------------------------------------------------
 
 //------------------------------------------------------------------------
+using ::editeng::SvxBorderLine;
 
 ScAttrArray::ScAttrArray( SCCOL nNewCol, SCTAB nNewTab, ScDocument* pDoc ) :
     nCol( nNewCol ),
diff --git a/sc/source/core/data/attrib.cxx b/sc/source/core/data/attrib.cxx
index df3aa00..c9fe133 100644
--- a/sc/source/core/data/attrib.cxx
+++ b/sc/source/core/data/attrib.cxx
@@ -75,7 +75,7 @@ TYPEINIT1(ScPageScaleToItem,    SfxPoolItem);
 //		allgemeine Hilfsfunktionen
 //
 
-sal_Bool ScHasPriority( const SvxBorderLine* pThis, const SvxBorderLine* pOther )
+sal_Bool ScHasPriority( const ::editeng::SvxBorderLine* pThis, const ::editeng::SvxBorderLine* pOther )
 {
 
     if (!pThis)
diff --git a/sc/source/core/data/column.cxx b/sc/source/core/data/column.cxx
index 86415b3..471c0dc 100644
--- a/sc/source/core/data/column.cxx
+++ b/sc/source/core/data/column.cxx
@@ -57,6 +57,7 @@
 //	nur Search ohne Optimierung!
 
 // STATIC DATA -----------------------------------------------------------
+using ::editeng::SvxBorderLine;
 using namespace formula;
 
 inline bool IsAmbiguousScriptNonZero( sal_uInt8 nScript )
diff --git a/sc/source/core/data/document.cxx b/sc/source/core/data/document.cxx
index 1841145..e8f9a8c 100644
--- a/sc/source/core/data/document.cxx
+++ b/sc/source/core/data/document.cxx
@@ -98,6 +98,7 @@
 #include <map>
 #include <limits>
 
+using ::editeng::SvxBorderLine;
 using namespace ::com::sun::star;
 
 namespace WritingMode2 = ::com::sun::star::text::WritingMode2;
diff --git a/sc/source/core/data/dpoutput.cxx b/sc/source/core/data/dpoutput.cxx
index 682237a..12d5ed2 100644
--- a/sc/source/core/data/dpoutput.cxx
+++ b/sc/source/core/data/dpoutput.cxx
@@ -157,7 +157,7 @@ void lcl_SetFrame( ScDocument* pDoc, SCTAB nTab,
                     SCCOL nCol1, SCROW nRow1, SCCOL nCol2, SCROW nRow2,
                     sal_uInt16 nWidth )
 {
-    SvxBorderLine aLine( NULL, nWidth, SOLID );
+    ::editeng::SvxBorderLine aLine( NULL, nWidth, ::editeng::SOLID );
     SvxBoxItem aBox( ATTR_BORDER );
     aBox.SetLine(&aLine, BOX_LINE_LEFT);
     aBox.SetLine(&aLine, BOX_LINE_TOP);
diff --git a/sc/source/core/data/fillinfo.cxx b/sc/source/core/data/fillinfo.cxx
index ecd899e..fa507f2 100644
--- a/sc/source/core/data/fillinfo.cxx
+++ b/sc/source/core/data/fillinfo.cxx
@@ -67,7 +67,7 @@ enum FillInfoLinePos
     };
 
 
-inline const SvxBorderLine* GetNullOrLine( const SvxBoxItem* pBox, FillInfoLinePos eWhich )
+inline const ::editeng::SvxBorderLine* GetNullOrLine( const SvxBoxItem* pBox, FillInfoLinePos eWhich )
 {
     if (pBox)
     {
diff --git a/sc/source/core/data/scdpoutputimpl.cxx b/sc/source/core/data/scdpoutputimpl.cxx
index f66f16c..02c244b 100644
--- a/sc/source/core/data/scdpoutputimpl.cxx
+++ b/sc/source/core/data/scdpoutputimpl.cxx
@@ -139,8 +139,8 @@ sal_Bool OutputImpl::AddCol( SCCOL nCol )
 void OutputImpl::OutputBlockFrame ( SCCOL nStartCol, SCROW nStartRow, SCCOL nEndCol, SCROW nEndRow, sal_Bool bHori )
 {
     Color color = SC_DP_FRAME_COLOR;
-    SvxBorderLine aLine( &color, SC_DP_FRAME_INNER_BOLD );
-    SvxBorderLine aOutLine( &color, SC_DP_FRAME_OUTER_BOLD );
+    ::editeng::SvxBorderLine aLine( &color, SC_DP_FRAME_INNER_BOLD );
+    ::editeng::SvxBorderLine aOutLine( &color, SC_DP_FRAME_OUTER_BOLD );
     
     SvxBoxItem aBox( ATTR_BORDER );
 
diff --git a/sc/source/core/data/stlpool.cxx b/sc/source/core/data/stlpool.cxx
index d069fb8..6cf0237 100644
--- a/sc/source/core/data/stlpool.cxx
+++ b/sc/source/core/data/stlpool.cxx
@@ -265,7 +265,7 @@ void ScStyleSheetPool::CreateStandardStyles()
     ScPageHFItem*	pHeaderItem		= new ScPageHFItem( ATTR_PAGE_HEADERRIGHT );
     ScPageHFItem*	pFooterItem		= new ScPageHFItem( ATTR_PAGE_FOOTERRIGHT );
     ScStyleSheet*	pSheet			= NULL;
-    SvxBorderLine	aBorderLine		( &aColBlack, DEF_LINE_WIDTH_2 );
+    ::editeng::SvxBorderLine	aBorderLine		( &aColBlack, DEF_LINE_WIDTH_2 );
     SvxBoxItem		aBoxItem		( ATTR_BORDER );
     SvxBoxInfoItem	aBoxInfoItem	( ATTR_BORDER_INNER );
 
diff --git a/sc/source/core/data/table2.cxx b/sc/source/core/data/table2.cxx
index 2ea2bf0..7d6a41e 100644
--- a/sc/source/core/data/table2.cxx
+++ b/sc/source/core/data/table2.cxx
@@ -1909,7 +1909,7 @@ void ScTable::ApplySelectionStyle(const ScStyleSheet& rStyle, const ScMarkData&
 
 
 void ScTable::ApplySelectionLineStyle( const ScMarkData& rMark,
-                            const SvxBorderLine* pLine, sal_Bool bColorOnly )
+                            const ::editeng::SvxBorderLine* pLine, sal_Bool bColorOnly )
 {
     if ( bColorOnly && !pLine )
         return;
diff --git a/sc/source/core/tool/autoform.cxx b/sc/source/core/tool/autoform.cxx
index 6831a6f..3db4a70 100755
--- a/sc/source/core/tool/autoform.cxx
+++ b/sc/source/core/tool/autoform.cxx
@@ -917,7 +917,7 @@ ScAutoFormat::ScAutoFormat(sal_uInt16 nLim, sal_uInt16 nDel, sal_Bool bDup):
 
     //  black thin border
     Color aBlack( COL_BLACK );
-    SvxBorderLine aLine( &aBlack, DEF_LINE_WIDTH_0 );
+    ::editeng::SvxBorderLine aLine( &aBlack, DEF_LINE_WIDTH_0 );
     SvxBoxItem aBox( ATTR_BORDER );
     aBox.SetLine(&aLine, BOX_LINE_LEFT);
     aBox.SetLine(&aLine, BOX_LINE_TOP);
diff --git a/sc/source/filter/excel/xestyle.cxx b/sc/source/filter/excel/xestyle.cxx
index 8b988f3..eb5075c 100644
--- a/sc/source/filter/excel/xestyle.cxx
+++ b/sc/source/filter/excel/xestyle.cxx
@@ -1546,7 +1546,7 @@ namespace {
 
 void lclGetBorderLine(
         sal_uInt8& rnXclLine, sal_uInt32& rnColorId,
-        const SvxBorderLine* pLine, XclExpPalette& rPalette, XclBiff eBiff )
+        const ::editeng::SvxBorderLine* pLine, XclExpPalette& rPalette, XclBiff eBiff )
 {
     rnXclLine = EXC_LINE_NONE;
     if( pLine )
@@ -1560,7 +1560,7 @@ void lclGetBorderLine(
         else if( nOuterWidth > DEF_LINE_WIDTH_1 )
         {
             rnXclLine = EXC_LINE_MEDIUM;
-            if ( pLine->GetStyle( ) == DASHED )
+            if ( pLine->GetStyle( ) == ::editeng::DASHED )
                 rnXclLine = EXC_LINE_MEDIUMDASHED;
         }
         else if( nOuterWidth > DEF_LINE_WIDTH_0 )
@@ -1568,10 +1568,10 @@ void lclGetBorderLine(
             rnXclLine = EXC_LINE_THIN;
             switch ( pLine->GetStyle( ) )
             {
-                case DASHED:
+                case ::editeng::DASHED:
                     rnXclLine = EXC_LINE_DASHED;
                     break;
-                case DOTTED:
+                case ::editeng::DOTTED:
                     rnXclLine = EXC_LINE_DOTTED;
                     break;
                 default:
diff --git a/sc/source/filter/html/htmlexp.cxx b/sc/source/filter/html/htmlexp.cxx
index b96d403..772b72b 100644
--- a/sc/source/filter/html/htmlexp.cxx
+++ b/sc/source/filter/html/htmlexp.cxx
@@ -102,6 +102,7 @@
 #include <com/sun/star/document/XDocumentProperties.hpp>
 #include <com/sun/star/document/XDocumentPropertiesSupplier.hpp>
 
+using ::editeng::SvxBorderLine;
 
 //========================================================================
 
@@ -511,22 +512,22 @@ void ScHTMLExport::BorderToStyle( ByteString& rOut, const char* pBorderName,
         (rOut += ByteString::CreateFromInt32( nPxWidth )) += "px ";
         switch ( pLine->GetStyle() )
         {
-            case SOLID:     rOut += "solid"; break;
-            case DOTTED:    rOut += "dotted"; break;
-            case DASHED:    rOut += "dashed"; break;
-            case DOUBLE:
-            case THINTHICK_SMALLGAP:
-            case THINTHICK_MEDIUMGAP:
-            case THINTHICK_LARGEGAP:
-            case THICKTHIN_SMALLGAP:
-            case THICKTHIN_MEDIUMGAP:
-            case THICKTHIN_LARGEGAP:
+            case ::editeng::SOLID:     rOut += "solid"; break;
+            case ::editeng::DOTTED:    rOut += "dotted"; break;
+            case ::editeng::DASHED:    rOut += "dashed"; break;
+            case ::editeng::DOUBLE:
+            case ::editeng::THINTHICK_SMALLGAP:
+            case ::editeng::THINTHICK_MEDIUMGAP:
+            case ::editeng::THINTHICK_LARGEGAP:
+            case ::editeng::THICKTHIN_SMALLGAP:
+            case ::editeng::THICKTHIN_MEDIUMGAP:
+            case ::editeng::THICKTHIN_LARGEGAP:
                             rOut += "double";
                             break;
-            case EMBOSSED:  rOut += "ridge"; break;
-            case ENGRAVED:  rOut += "groove"; break;
-            case OUTSET:    rOut += "outset"; break;
-            case INSET:     rOut += "inset"; break;
+            case ::editeng::EMBOSSED:  rOut += "ridge"; break;
+            case ::editeng::ENGRAVED:  rOut += "groove"; break;
+            case ::editeng::OUTSET:    rOut += "outset"; break;
+            case ::editeng::INSET:     rOut += "inset"; break;
             default:        rOut += "hidden";
         }
         rOut += " #";
diff --git a/sc/source/filter/html/htmlpars.cxx b/sc/source/filter/html/htmlpars.cxx
index 05d7139..7af88be 100644
--- a/sc/source/filter/html/htmlpars.cxx
+++ b/sc/source/filter/html/htmlpars.cxx
@@ -67,7 +67,7 @@
 #include <com/sun/star/document/XDocumentProperties.hpp>
 #include <com/sun/star/document/XDocumentPropertiesSupplier.hpp>
 
-
+using ::editeng::SvxBorderLine;
 using namespace ::com::sun::star;
 
 
@@ -2192,8 +2192,8 @@ void ScHTMLTable::ApplyCellBorders( ScDocument* pDoc, const ScAddress& rFirstPos
         const SCROW nLastRow = maSize.mnRows - 1;
         const long nOuterLine = DEF_LINE_WIDTH_2;
         const long nInnerLine = DEF_LINE_WIDTH_0;
-        SvxBorderLine aOuterLine( NULL, nOuterLine, SOLID );
-        SvxBorderLine aInnerLine( NULL, nInnerLine, SOLID );
+        SvxBorderLine aOuterLine( NULL, nOuterLine, ::editeng::SOLID );
+        SvxBorderLine aInnerLine( NULL, nInnerLine, ::editeng::SOLID );
         SvxBoxItem aBorderItem( ATTR_BORDER );
 
         for( SCCOL nCol = 0; nCol <= nLastCol; ++nCol )
diff --git a/sc/source/filter/inc/excrecds.hxx b/sc/source/filter/inc/excrecds.hxx
index 41f05ef..18e595f 100644
--- a/sc/source/filter/inc/excrecds.hxx
+++ b/sc/source/filter/inc/excrecds.hxx
@@ -51,8 +51,6 @@
 
 //------------------------------------------------------------------ Forwards -
 
-class SvxBorderLine;
-
 class SvStream;
 class Font;
 class List;
diff --git a/sc/source/filter/inc/htmlexp.hxx b/sc/source/filter/inc/htmlexp.hxx
index ab8cc46..cc47baa 100644
--- a/sc/source/filter/inc/htmlexp.hxx
+++ b/sc/source/filter/inc/htmlexp.hxx
@@ -47,7 +47,8 @@ class OutputDevice;
 class ScDrawLayer;
 class SvStringsSortDtor;
 class ScEditCell;
-class SvxBorderLine;
+
+namespace editeng { class SvxBorderLine; }
 
 struct ScHTMLStyle
 {	// Defaults aus StyleSheet
@@ -153,7 +154,7 @@ class ScHTMLExport : public ScExportBase
                                         SCCOL nEndCol, SCROW nEndRow );
 
     void				BorderToStyle( ByteString& rOut, const char* pBorderName,
-                                       const SvxBorderLine* pLine, bool& bInsertSemicolon );
+                                       const ::editeng::SvxBorderLine* pLine, bool& bInsertSemicolon );
 
     sal_uInt16				GetFontSizeNumber( sal_uInt16 nHeight );
     const char*			GetFontSizeCss( sal_uInt16 nHeight );
diff --git a/sc/source/filter/inc/lotattr.hxx b/sc/source/filter/inc/lotattr.hxx
index b5e2b7d..e7540b1 100644
--- a/sc/source/filter/inc/lotattr.hxx
+++ b/sc/source/filter/inc/lotattr.hxx
@@ -39,11 +39,12 @@
 class ScDocument;
 class ScDocumentPool;
 class ScPatternAttr;
-class SvxBorderLine;
 class SvxColorItem;
 class Color;
 class LotAttrTable;
 
+namespace editeng { class SvxBorderLine; }
+
 struct LotAttrWK3
 {
     sal_uInt8 nFont;
@@ -101,7 +102,7 @@ private:
         ( ( sal_uInt8* ) &rOut )[ 3 ] = rAttr.nBack;
     }
 
-    static void LotusToScBorderLine( sal_uInt8 nLine, SvxBorderLine& );
+    static void LotusToScBorderLine( sal_uInt8 nLine, ::editeng::SvxBorderLine& );
 
     const SvxColorItem&	GetColorItem( const sal_uInt8 nLotIndex ) const;
 
diff --git a/sc/source/filter/inc/lotimpop.hxx b/sc/source/filter/inc/lotimpop.hxx
index 9e09036..24db741 100644
--- a/sc/source/filter/inc/lotimpop.hxx
+++ b/sc/source/filter/inc/lotimpop.hxx
@@ -39,7 +39,6 @@
 
 class ScFormulaCell;
 class LotusFontBuffer;
-class SvxBorderLine;
 
 
 class ImportLotus : public ImportTyp
diff --git a/sc/source/filter/lotus/lotattr.cxx b/sc/source/filter/lotus/lotattr.cxx
index ce71a8f..45ee164 100644
--- a/sc/source/filter/lotus/lotattr.cxx
+++ b/sc/source/filter/lotus/lotattr.cxx
@@ -124,7 +124,7 @@ const ScPatternAttr& LotAttrCache::GetPattAttr( const LotAttrWK3& rAttr )
     if( nLine )
     {
         SvxBoxItem		aBox( ATTR_BORDER );
-        SvxBorderLine	aTop, aLeft, aBottom, aRight;
+        ::editeng::SvxBorderLine	aTop, aLeft, aBottom, aRight;
 
         LotusToScBorderLine( nLine, aLeft );
         nLine >>= 2;
@@ -168,19 +168,19 @@ const ScPatternAttr& LotAttrCache::GetPattAttr( const LotAttrWK3& rAttr )
 }
 
 
-void LotAttrCache::LotusToScBorderLine( sal_uInt8 nLine, SvxBorderLine& aBL )
+void LotAttrCache::LotusToScBorderLine( sal_uInt8 nLine, ::editeng::SvxBorderLine& aBL )
 {
     nLine &= 0x03;
 
     switch ( nLine )
     {
         default:
-        case 0: aBL.SetStyle( NO_STYLE ); break;
+        case 0: aBL.SetStyle( ::editeng::NO_STYLE ); break;
         case 1: aBL.SetWidth( DEF_LINE_WIDTH_1 ); break;
         case 2: aBL.SetWidth( DEF_LINE_WIDTH_2 ); break;
         case 3:
         {
-            aBL.SetStyle( DOUBLE );
+            aBL.SetStyle( ::editeng::DOUBLE );
             aBL.SetWidth( DEF_LINE_WIDTH_1 );
         }
         break;
diff --git a/sc/source/filter/starcalc/scflt.cxx b/sc/source/filter/starcalc/scflt.cxx
index d1f18e2..e01e3bd 100644
--- a/sc/source/filter/starcalc/scflt.cxx
+++ b/sc/source/filter/starcalc/scflt.cxx
@@ -839,7 +839,7 @@ void Sc10PageCollection::PutToDoc( ScDocument* pDoc )
               lcl_ChangeColor(cTop, ColorTop);
               lcl_ChangeColor(cRight, ColorRight);
               lcl_ChangeColor(cBottom, ColorBottom);
-              SvxBorderLine aLine;
+              ::editeng::SvxBorderLine aLine;
               SvxBoxItem aBox( ATTR_BORDER );
               aLine.SetWidth(nLeft);
               aLine.SetColor(ColorLeft);
@@ -1275,7 +1275,7 @@ void Sc10Import::LoadPatternCollection()
                     lcl_ChangeColor( cRight, ColorRight );
                     lcl_ChangeColor( cBottom, ColorBottom );
 
-                    SvxBorderLine	aLine;
+                    ::editeng::SvxBorderLine	aLine;
                     SvxBoxItem      aBox( ATTR_BORDER );
 
                     aLine.SetWidth( nLeft );
@@ -1930,7 +1930,7 @@ void Sc10Import::LoadColAttr(SCCOL Col, SCTAB Tab)
         if( ( nStart <= nEnd ) && ( nValue != 0 ) )
         {
             ScPatternAttr   aScPattern(pDoc->GetPool());
-            SvxBorderLine	aLine;
+            ::editeng::SvxBorderLine	aLine;
             SvxBoxItem      aBox( ATTR_BORDER );
 
             aLine.SetWidth( nLeft );
diff --git a/sc/source/ui/inc/autofmt.hxx b/sc/source/ui/inc/autofmt.hxx
index 9156e8c..e802922 100644
--- a/sc/source/ui/inc/autofmt.hxx
+++ b/sc/source/ui/inc/autofmt.hxx
@@ -112,27 +112,27 @@ private:
                               Font& rCTLFont );
 
     SC_DLLPRIVATE String	MakeNumberString( String cellString, sal_Bool bAddDec );
-    SC_DLLPRIVATE void	DrawFrameLine	( const SvxBorderLine&	rLineD,
+    SC_DLLPRIVATE void	DrawFrameLine	( const ::editeng::SvxBorderLine&	rLineD,
                               Point					from,
                               Point					to,
                               sal_Bool					bHorizontal,
-                              const SvxBorderLine&	rLineLT,
-                              const SvxBorderLine&	rLineL,
-                              const SvxBorderLine&	rLineLB,
-                              const SvxBorderLine&	rLineRT,
-                              const SvxBorderLine&	rLineR,
-                              const SvxBorderLine&	rLineRB );
+                              const ::editeng::SvxBorderLine&	rLineLT,
+                              const ::editeng::SvxBorderLine&	rLineL,
+                              const ::editeng::SvxBorderLine&	rLineLB,
+                              const ::editeng::SvxBorderLine&	rLineRT,
+                              const ::editeng::SvxBorderLine&	rLineR,
+                              const ::editeng::SvxBorderLine&	rLineRB );
     SC_DLLPRIVATE void CheckPriority	( sal_uInt16			nCurLine,
                               AutoFmtLine		eLine,
-                              SvxBorderLine&	rLine );
+                              ::editeng::SvxBorderLine&	rLine );
     SC_DLLPRIVATE void	GetLines		( sal_uInt16 nIndex, AutoFmtLine eLine,
-                              SvxBorderLine&	rLineD,
-                              SvxBorderLine&	rLineLT,
-                              SvxBorderLine&	rLineL,
-                              SvxBorderLine&	rLineLB,
-                              SvxBorderLine&	rLineRT,
-                              SvxBorderLine&	rLineR,
-                              SvxBorderLine&	rLineRB );
+                              ::editeng::SvxBorderLine&	rLineD,
+                              ::editeng::SvxBorderLine&	rLineLT,
+                              ::editeng::SvxBorderLine&	rLineL,
+                              ::editeng::SvxBorderLine&	rLineLB,
+                              ::editeng::SvxBorderLine&	rLineRT,
+                              ::editeng::SvxBorderLine&	rLineR,
+                              ::editeng::SvxBorderLine&	rLineRB );
 };
 
 #endif // SC_AUTOFMT_HXX
diff --git a/sc/source/ui/inc/tabvwsh.hxx b/sc/source/ui/inc/tabvwsh.hxx
index 4913f1d..f14d4c5 100644
--- a/sc/source/ui/inc/tabvwsh.hxx
+++ b/sc/source/ui/inc/tabvwsh.hxx
@@ -46,7 +46,6 @@ class SdrOle2Obj;
 class SfxBindings;
 class SfxChildWindow;
 class SfxModelessDialog;
-class SvxBorderLine;
 class SvxBoxObjectRef;
 class SvxNumberInfoItem;
 struct SfxChildWinInfo;
@@ -70,6 +69,8 @@ class ScNavigatorSettings;
 
 struct ScHeaderFieldData;
 
+namespace editeng { class SvxBorderLine; }
+
 namespace com { namespace sun { namespace star { namespace frame {
     class XDispatchProviderInterceptor;
 } } } }
@@ -130,7 +131,7 @@ private:
 
     ScInputHandler*			pInputHandler;				// fuer OLE-Eingabezeile
 
-    SvxBorderLine*			pCurFrameLine;
+    ::editeng::SvxBorderLine*			pCurFrameLine;
 
     ::com::sun::star::uno::Reference<
         ::com::sun::star::frame::XDispatchProviderInterceptor >
@@ -260,8 +261,8 @@ public:
 
     void			SetActive();
 
-    SvxBorderLine*	GetDefaultFrameLine() const { return pCurFrameLine; }
-    void 			SetDefaultFrameLine(const SvxBorderLine* pLine );
+    ::editeng::SvxBorderLine*	GetDefaultFrameLine() const { return pCurFrameLine; }
+    void 			SetDefaultFrameLine(const ::editeng::SvxBorderLine* pLine );
 
     SC_DLLPUBLIC void			Execute( SfxRequest& rReq );
     SC_DLLPUBLIC void			GetState( SfxItemSet& rSet );
diff --git a/sc/source/ui/inc/viewfunc.hxx b/sc/source/ui/inc/viewfunc.hxx
index 0601d52..deca468 100644
--- a/sc/source/ui/inc/viewfunc.hxx
+++ b/sc/source/ui/inc/viewfunc.hxx
@@ -46,7 +46,6 @@ class ScPatternAttr;
 class ScAutoFormatData;
 class SvxSearchItem;
 class SfxItemSet;
-class SvxBorderLine;
 class SvxBoxItem;
 class SvxBoxInfoItem;
 class SfxStyleSheetBase;
@@ -67,6 +66,8 @@ class SvxHyperlinkItem;
 class ScTransferObj;
 class ScTableProtection;
 
+namespace editeng { class SvxBorderLine; }
+
 namespace com { namespace sun { namespace star { namespace datatransfer { class XTransferable; } } } }
 
 //==================================================================
@@ -298,7 +299,7 @@ public:
 
     void			InsertDraw();
 
-    void			SetSelectionFrameLines( const SvxBorderLine* pLine,
+    void			SetSelectionFrameLines( const ::editeng::SvxBorderLine* pLine,
                                             sal_Bool bColorOnly );
 
     void            SetNoteText( const ScAddress& rPos, const String& rNoteText );
@@ -345,9 +346,9 @@ public:
 
                                                 // interne Hilfsfunktionen
 protected:
-    void			UpdateLineAttrs( SvxBorderLine&		  rLine,
-                                     const SvxBorderLine* pDestLine,
-                                     const SvxBorderLine* pSrcLine,
+    void			UpdateLineAttrs( ::editeng::SvxBorderLine&		  rLine,
+                                     const ::editeng::SvxBorderLine* pDestLine,
+                                     const ::editeng::SvxBorderLine* pSrcLine,
                                      sal_Bool 				  bColor );
 
 
diff --git a/sc/source/ui/miscdlgs/autofmt.cxx b/sc/source/ui/miscdlgs/autofmt.cxx
index f1bec82..440cf14 100644
--- a/sc/source/ui/miscdlgs/autofmt.cxx
+++ b/sc/source/ui/miscdlgs/autofmt.cxx
@@ -470,7 +470,7 @@ void ScAutoFmtPreview::CalcCellArray( sal_Bool bFitWidthP )
 
 //------------------------------------------------------------------------
 
-inline void lclSetStyleFromBorder( svx::frame::Style& rStyle, const SvxBorderLine* pBorder )
+inline void lclSetStyleFromBorder( svx::frame::Style& rStyle, const ::editeng::SvxBorderLine* pBorder )
 {
     rStyle.Set( pBorder, 1.0 / TWIPS_PER_POINT, 5 );
 }
diff --git a/sc/source/ui/unoobj/cellsuno.cxx b/sc/source/ui/unoobj/cellsuno.cxx
index 0787e47..55369e7 100644
--- a/sc/source/ui/unoobj/cellsuno.cxx
+++ b/sc/source/ui/unoobj/cellsuno.cxx
@@ -949,11 +949,11 @@ ScSubTotalFunc lcl_SummaryToSubTotal( sheet::GeneralFunction eSummary )
 
 //------------------------------------------------------------------------
 
-const SvxBorderLine* ScHelperFunctions::GetBorderLine( SvxBorderLine& rLine, const table::BorderLine& rStruct )
+const ::editeng::SvxBorderLine* ScHelperFunctions::GetBorderLine( ::editeng::SvxBorderLine& rLine, const table::BorderLine& rStruct )
 {
     //	Calc needs Twips, and there are 1/100mm in the Uno structure
     const table::BorderLine2& rBorder2 = static_cast< const table::BorderLine2& >( rStruct );
-    rLine.SetStyle( SvxBorderStyle( rBorder2.LineStyle ) );
+    rLine.SetStyle( ::editeng::SvxBorderStyle( rBorder2.LineStyle ) );
     rLine.GuessLinesWidths( rLine.GetStyle(),
         (sal_uInt16)HMMToTwips( rStruct.OuterLineWidth ),
         (sal_uInt16)HMMToTwips( rStruct.InnerLineWidth ),
@@ -968,7 +968,7 @@ const SvxBorderLine* ScHelperFunctions::GetBorderLine( SvxBorderLine& rLine, con
 
 void ScHelperFunctions::FillBoxItems( SvxBoxItem& rOuter, SvxBoxInfoItem& rInner, const table::TableBorder& rBorder )
 {
-    SvxBorderLine aLine;
+    ::editeng::SvxBorderLine aLine;
     rOuter.SetDistance( (sal_uInt16)HMMToTwips( rBorder.Distance ) );
     rOuter.SetLine( ScHelperFunctions::GetBorderLine( aLine, rBorder.TopLine ),		BOX_LINE_TOP );
     rOuter.SetLine( ScHelperFunctions::GetBorderLine( aLine, rBorder.BottomLine ),		BOX_LINE_BOTTOM );
@@ -986,7 +986,7 @@ void ScHelperFunctions::FillBoxItems( SvxBoxItem& rOuter, SvxBoxInfoItem& rInner
     rInner.SetTable( sal_True );
 }
 
-void ScHelperFunctions::FillBorderLine( table::BorderLine& rStruct, const SvxBorderLine* pLine )
+void ScHelperFunctions::FillBorderLine( table::BorderLine& rStruct, const ::editeng::SvxBorderLine* pLine )
 {
     if (pLine)
     {
diff --git a/sc/source/ui/view/formatsh.cxx b/sc/source/ui/view/formatsh.cxx
index b44f09d..9d61475 100644
--- a/sc/source/ui/view/formatsh.cxx
+++ b/sc/source/ui/view/formatsh.cxx
@@ -1500,14 +1500,14 @@ void ScFormatShell::ExecuteAttr( SfxRequest& rReq )
             case SID_FRAME_LINESTYLE:
                 {
                     // Default-Linie aktualisieren
-                    const SvxBorderLine* pLine =
+                    const ::editeng::SvxBorderLine* pLine =
                             ((const SvxLineItem&)
                                 pNewAttrs->Get( SID_FRAME_LINESTYLE )).
                                 GetLine();
 
                     if ( pLine )
                     {
-                        SvxBorderLine* pDefLine = pTabViewShell->GetDefaultFrameLine();
+                        ::editeng::SvxBorderLine* pDefLine = pTabViewShell->GetDefaultFrameLine();
 
                         if ( pDefLine )
                         {
@@ -1525,7 +1525,7 @@ void ScFormatShell::ExecuteAttr( SfxRequest& rReq )
                     else
                     {
                         Color           aColorBlack( COL_BLACK );
-                        SvxBorderLine   aDefLine( &aColorBlack, 20, SOLID );
+                        ::editeng::SvxBorderLine   aDefLine( &aColorBlack, 20, ::editeng::SOLID );
                         pTabViewShell->SetDefaultFrameLine( &aDefLine );
                         pTabViewShell->SetSelectionFrameLines( NULL, false );
                     }
@@ -1534,7 +1534,7 @@ void ScFormatShell::ExecuteAttr( SfxRequest& rReq )
 
             case SID_FRAME_LINECOLOR:
                 {
-                    SvxBorderLine*  pDefLine = pTabViewShell->GetDefaultFrameLine();
+                    ::editeng::SvxBorderLine*  pDefLine = pTabViewShell->GetDefaultFrameLine();
                     const Color&    rColor = ((const SvxColorItem&)
                                         pNewAttrs->Get( SID_FRAME_LINECOLOR )).
                                             GetValue();
@@ -1547,7 +1547,7 @@ void ScFormatShell::ExecuteAttr( SfxRequest& rReq )
                     }
                     else
                     {
-                        SvxBorderLine   aDefLine( &rColor, 20, SOLID );
+                        ::editeng::SvxBorderLine   aDefLine( &rColor, 20, ::editeng::SOLID );
                         pTabViewShell->SetDefaultFrameLine( &aDefLine );
                         pTabViewShell->SetSelectionFrameLines( &aDefLine, false );
                     }
@@ -1557,7 +1557,7 @@ void ScFormatShell::ExecuteAttr( SfxRequest& rReq )
             case SID_ATTR_BORDER_OUTER:
             case SID_ATTR_BORDER:
                 {
-                    SvxBorderLine*          pDefLine = pTabViewShell->GetDefaultFrameLine();
+                    ::editeng::SvxBorderLine*          pDefLine = pTabViewShell->GetDefaultFrameLine();
                     const ScPatternAttr*    pOldAttrs = pTabViewShell->GetSelectionPattern();
                     ScDocument*             pDoc = GetViewData()->GetDocument();
                     SfxItemSet*             pOldSet =
@@ -1676,7 +1676,7 @@ void ScFormatShell::GetAttrState( SfxItemSet& rSet )
 {
     ScTabViewShell*	pTabViewShell  	= GetViewData()->GetViewShell();
     const SfxItemSet&	 rAttrSet	= pTabViewShell->GetSelectionPattern()->GetItemSet();
-    const SvxBorderLine* pLine      = pTabViewShell->GetDefaultFrameLine();
+    const ::editeng::SvxBorderLine* pLine      = pTabViewShell->GetDefaultFrameLine();
     const SvxBrushItem&  rBrushItem = (const SvxBrushItem&)rAttrSet.Get( ATTR_BACKGROUND );
     SfxWhichIter aIter( rSet );
     sal_uInt16 nWhich = aIter.FirstWhich();
diff --git a/sc/source/ui/view/output.cxx b/sc/source/ui/view/output.cxx
index efdd182..5cf2415 100644
--- a/sc/source/ui/view/output.cxx
+++ b/sc/source/ui/view/output.cxx
@@ -1243,7 +1243,7 @@ void ScOutputData::DrawFrame()
 
 //	Linie unter der Zelle
 
-const SvxBorderLine* lcl_FindHorLine( ScDocument* pDoc,
+const ::editeng::SvxBorderLine* lcl_FindHorLine( ScDocument* pDoc,
                         SCCOL nCol, SCROW nRow, SCTAB nTab, sal_uInt16 nRotDir,
                         sal_Bool bTopLine )
 {
@@ -1279,12 +1279,12 @@ const SvxBorderLine* lcl_FindHorLine( ScDocument* pDoc,
 
     if (bTopLine)
         --nRow;
-    const SvxBorderLine* pThisBottom;
+    const ::editeng::SvxBorderLine* pThisBottom;
     if ( ValidRow(nRow) )
         pThisBottom = ((const SvxBoxItem*)pDoc->GetAttr( nCol, nRow, nTab, ATTR_BORDER ))->GetBottom();
     else
         pThisBottom = NULL;
-    const SvxBorderLine* pNextTop;
+    const ::editeng::SvxBorderLine* pNextTop;
     if ( nRow < MAXROW )
         pNextTop = ((const SvxBoxItem*)pDoc->GetAttr( nCol, nRow+1, nTab, ATTR_BORDER ))->GetTop();
     else
@@ -1491,10 +1491,10 @@ void ScOutputData::DrawRotatedFrame( const Color* pForceColor )
                         if ( nX < nX1 || nX > nX2 )		// Attribute in FillInfo nicht gesetzt
                         {
                             //!	Seitengrenzen fuer Druck beruecksichtigen !!!!!
-                            const SvxBorderLine* pLeftLine;
-                            const SvxBorderLine* pTopLine;
-                            const SvxBorderLine* pRightLine;
-                            const SvxBorderLine* pBottomLine;
+                            const ::editeng::SvxBorderLine* pLeftLine;
+                            const ::editeng::SvxBorderLine* pTopLine;
+                            const ::editeng::SvxBorderLine* pRightLine;
+                            const ::editeng::SvxBorderLine* pBottomLine;
                             pDoc->GetBorderLines( nX, nY, nTab,
                                     &pLeftLine, &pTopLine, &pRightLine, &pBottomLine );
                             aTopLine.Set( pTopLine, nPPTY );
diff --git a/sc/source/ui/view/printfun.cxx b/sc/source/ui/view/printfun.cxx
index e678e33..7fd44dc 100644
--- a/sc/source/ui/view/printfun.cxx
+++ b/sc/source/ui/view/printfun.cxx
@@ -178,7 +178,7 @@ size_t ScPageRowEntry::CountVisible() const
 
 //------------------------------------------------------------------------
 
-long lcl_LineTotal(const SvxBorderLine* pLine)
+long lcl_LineTotal(const ::editeng::SvxBorderLine* pLine)
 {
     return pLine ? ( pLine->GetOutWidth() + pLine->GetInWidth() + pLine->GetDistance() ) : 0;
 }
diff --git a/sc/source/ui/view/tabvwsh4.cxx b/sc/source/ui/view/tabvwsh4.cxx
index fb47e42..fdc39f5 100644
--- a/sc/source/ui/view/tabvwsh4.cxx
+++ b/sc/source/ui/view/tabvwsh4.cxx
@@ -1505,7 +1505,7 @@ void ScTabViewShell::Construct( sal_uInt8 nForceDesignMode )
     SetPool( &SC_MOD()->GetPool() );
     SetWindow( GetActiveWin() );
 
-    pCurFrameLine	= new SvxBorderLine( &aColBlack, 20, SOLID );
+    pCurFrameLine	= new ::editeng::SvxBorderLine( &aColBlack, 20, ::editeng::SOLID );
     pPivotSource	= new ScArea;
     StartListening(*GetViewData()->GetDocShell(),sal_True);
     StartListening(*GetViewFrame(),sal_True);
diff --git a/sc/source/ui/view/tabvwsh8.cxx b/sc/source/ui/view/tabvwsh8.cxx
index 7a2f7a4..8520b5a 100644
--- a/sc/source/ui/view/tabvwsh8.cxx
+++ b/sc/source/ui/view/tabvwsh8.cxx
@@ -42,12 +42,12 @@
 
 //------------------------------------------------------------------
 
-void ScTabViewShell::SetDefaultFrameLine( const SvxBorderLine* pLine )
+void ScTabViewShell::SetDefaultFrameLine( const ::editeng::SvxBorderLine* pLine )
 {
     if ( pLine )
     {
         delete pCurFrameLine;
-        pCurFrameLine = new SvxBorderLine( &pLine->GetColor(),
+        pCurFrameLine = new ::editeng::SvxBorderLine( &pLine->GetColor(),
                                             pLine->GetWidth(),
                                             pLine->GetStyle() );
     }
diff --git a/sc/source/ui/view/viewfun2.cxx b/sc/source/ui/view/viewfun2.cxx
index 70b6ff7..ec16f0f 100644
--- a/sc/source/ui/view/viewfun2.cxx
+++ b/sc/source/ui/view/viewfun2.cxx
@@ -103,6 +103,7 @@
 using namespace com::sun::star;
 using ::rtl::OUStringBuffer;
 using ::rtl::OUString;
+using ::editeng::SvxBorderLine;
 
 using ::std::vector;
 using ::std::auto_ptr;


More information about the Libreoffice-commits mailing list
diff --git a/sc/source/filter/excel/xistyle.cxx b/sc/source/filter/excel/xistyle.cxx
index bac3fe6..d4eb332 100644
--- a/sc/source/filter/excel/xistyle.cxx
+++ b/sc/source/filter/excel/xistyle.cxx
@@ -908,26 +908,26 @@ namespace {
 #define XLS_LINE_WIDTH_MEDIUM 18
 #define XLS_LINE_WIDTH_THICK  24
 
-/** Converts the passed line style to a SvxBorderLine, or returns false, if style is "no line". */
-bool lclConvertBorderLine( SvxBorderLine& rLine, const XclImpPalette& rPalette, sal_uInt8 nXclLine, sal_uInt16 nXclColor )
+/** Converts the passed line style to a ::editeng::SvxBorderLine, or returns false, if style is "no line". */
+bool lclConvertBorderLine( ::editeng::SvxBorderLine& rLine, const XclImpPalette& rPalette, sal_uInt8 nXclLine, sal_uInt16 nXclColor )
 {
     static const sal_uInt16 ppnLineParam[][ 4 ] =
     {
         //  outer width,           type
-        {   0,                     SOLID },                // 0 = none
-        {   XLS_LINE_WIDTH_THIN,   SOLID },                // 1 = thin
-        {   XLS_LINE_WIDTH_MEDIUM, SOLID },                // 2 = medium
-        {   XLS_LINE_WIDTH_THIN,   DASHED },               // 3 = dashed
-        {   XLS_LINE_WIDTH_THIN,   DOTTED },               // 4 = dotted
-        {   XLS_LINE_WIDTH_THICK,  SOLID },                // 5 = thick
-        {   XLS_LINE_WIDTH_THIN,   DOUBLE },                 // 6 = double
-        {   XLS_LINE_WIDTH_HAIR,   SOLID },                // 7 = hair
-        {   XLS_LINE_WIDTH_MEDIUM, DASHED },               // 8 = med dash
-        {   XLS_LINE_WIDTH_THIN,   SOLID },                // 9 = thin dashdot
-        {   XLS_LINE_WIDTH_MEDIUM, SOLID },                // A = med dashdot
-        {   XLS_LINE_WIDTH_THIN,   SOLID },                // B = thin dashdotdot
-        {   XLS_LINE_WIDTH_MEDIUM, SOLID },                // C = med dashdotdot
-        {   XLS_LINE_WIDTH_MEDIUM, SOLID }                 // D = med slant dashdot
+        {   0,                     ::editeng::SOLID },                // 0 = none
+        {   XLS_LINE_WIDTH_THIN,   ::editeng::SOLID },                // 1 = thin
+        {   XLS_LINE_WIDTH_MEDIUM, ::editeng::SOLID },                // 2 = medium
+        {   XLS_LINE_WIDTH_THIN,   ::editeng::DASHED },               // 3 = dashed
+        {   XLS_LINE_WIDTH_THIN,   ::editeng::DOTTED },               // 4 = dotted
+        {   XLS_LINE_WIDTH_THICK,  ::editeng::SOLID },                // 5 = thick
+        {   XLS_LINE_WIDTH_THIN,   ::editeng::DOUBLE },                 // 6 = double
+        {   XLS_LINE_WIDTH_HAIR,   ::editeng::SOLID },                // 7 = hair
+        {   XLS_LINE_WIDTH_MEDIUM, ::editeng::DASHED },               // 8 = med dash
+        {   XLS_LINE_WIDTH_THIN,   ::editeng::SOLID },                // 9 = thin dashdot
+        {   XLS_LINE_WIDTH_MEDIUM, ::editeng::SOLID },                // A = med dashdot
+        {   XLS_LINE_WIDTH_THIN,   ::editeng::SOLID },                // B = thin dashdotdot
+        {   XLS_LINE_WIDTH_MEDIUM, ::editeng::SOLID },                // C = med dashdotdot
+        {   XLS_LINE_WIDTH_MEDIUM, ::editeng::SOLID }                 // D = med slant dashdot
     };
 
     if( nXclLine == EXC_LINE_NONE )
@@ -937,7 +937,7 @@ bool lclConvertBorderLine( SvxBorderLine& rLine, const XclImpPalette& rPalette,
 
     rLine.SetColor( rPalette.GetColor( nXclColor ) );
     rLine.SetWidth( ppnLineParam[ nXclLine ][ 0 ] );
-    rLine.SetStyle( (SvxBorderStyle)ppnLineParam[ nXclLine ][ 1 ] );
+    rLine.SetStyle( (::editeng::SvxBorderStyle)ppnLineParam[ nXclLine ][ 1 ] );
     return true;
 }
 
@@ -948,7 +948,7 @@ void XclImpCellBorder::FillToItemSet( SfxItemSet& rItemSet, const XclImpPalette&
     if( mbLeftUsed || mbRightUsed || mbTopUsed || mbBottomUsed )
     {
         SvxBoxItem aBoxItem( ATTR_BORDER );
-        SvxBorderLine aLine;
+        ::editeng::SvxBorderLine aLine;
         if( mbLeftUsed && lclConvertBorderLine( aLine, rPalette, mnLeftLine, mnLeftColor ) )
             aBoxItem.SetLine( &aLine, BOX_LINE_LEFT );
         if( mbRightUsed && lclConvertBorderLine( aLine, rPalette, mnRightLine, mnRightColor ) )
@@ -963,7 +963,7 @@ void XclImpCellBorder::FillToItemSet( SfxItemSet& rItemSet, const XclImpPalette&
     {
         SvxLineItem aTLBRItem( ATTR_BORDER_TLBR );
         SvxLineItem aBLTRItem( ATTR_BORDER_BLTR );
-        SvxBorderLine aLine;
+        ::editeng::SvxBorderLine aLine;
         if( lclConvertBorderLine( aLine, rPalette, mnDiagLine, mnDiagColor ) )
         {
             if( mbDiagTLtoBR )